pub struct KBucket {}Implementations
Sourceimpl KBucket
impl KBucket
Sourcepub fn arbiter(&self)
pub fn arbiter(&self)
Default arbiter function for contacts with the same id. Uses contact.vectorClock to select which contact to update the k-bucket with. Contact with larger vectorClock field will be selected. If vectorClock is the same, candidat will be selected.
Sourcepub fn distance(&self)
pub fn distance(&self)
Default distance function. Finds the XOR distance between firstId and secondId.
Sourcepub fn closest(&self)
pub fn closest(&self)
Get the n closest contacts to the provided node id. “Closest” here means: closest according to the XOR metric of the contact node id.
pub fn is_empty(&self) -> bool